==> SyL-0.14.0.tar.gz: SyL/include/framework/Filter/SyL_FilterAuth.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_FilterAuth.php,v 1.7 2007/08/27 06:00:04 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ե륿饹
 */
require_once SYL_INCLUDE_DIR . '/framework/SyL_Filter.php';
/**
 * ǧڥ饹
 */
require_once SYL_INCLUDE_DIR . '/framework/SyL_Auth.php';

/**
 * ǧڥե륿饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_FilterAuth.php,v 1.7 2007/08/27 06:00:04 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_FilterAuth extends SyL_Filter
{
    /**
     * ǧڥ֥
     * 
     * @access private
     * @var object
     */
    var $auth = null;
    /**
     * ǧڼ¹Ƚե饰
     * 
     * @access private
     * @var bool
     */
    var $login = null;

    /**
     * 󥹥ȥ饯
     *
     * @access public
     */
    function SyL_FilterAuth()
    {
        // ǧڥ֥Ⱥ
        $this->auth =& SyL_Auth::singleton();
    }

    /**
     * ǧȽ or ǧڼ¹
     *
     * @access public
     * @param object ǡ֥
     */
    function preAction(&$data)
    {
        // ǧڥꥢȽ
        if ($this->auth->isAuthArea()) {
            // 󥢥Ƚ
            if ($this->auth->isLoginAction()) {
                // ¹
                $this->login = $this->auth->doLogin();
                if (!$this->login) {
                    // å󥨥顼̤إ쥯
                    SyL_Auth::redirectSessionError('login=false');
                }
            } else {
                // ֤Ƚ
                if (!$this->auth->isLogin()) {
                    // ̤ξ
                    // å󥨥顼̤إ쥯
                    SyL_Auth::redirectSessionError();
                }
            }
        }
    }

    /**
     * ϡTOP̤˥쥯
     *
     * @access public
     * @param object ǡ֥
     */
    function postAction(&$data)
    {
        // ǧڥꥢȽ
        if (is_bool($this->login) && $this->login) {
            // TOPإ쥯
            SyL_Auth::redirectTop();
        }
    }
}

?>

==> SyL-0.14.6.tar.gz: SyL/include/framework/Filter/SyL_FilterAuth.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_FilterAuth.php,v 1.8 2007/09/02 14:40:34 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ե륿饹
 */
require_once SYL_INCLUDE_DIR . '/framework/SyL_Filter.php';
/**
 * ǧڥ饹
 */
require_once SYL_INCLUDE_DIR . '/framework/SyL_Auth.php';

/**
 * ǧڥե륿饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_FilterAuth.php,v 1.8 2007/09/02 14:40:34 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_FilterAuth extends SyL_Filter
{
    /**
     * ǧڥ֥
     * 
     * @access private
     * @var object
     */
    var $auth = null;
    /**
     * ǧڼ¹Ƚե饰
     * 
     * @access private
     * @var bool
     */
    var $login = null;

    /**
     * 󥹥ȥ饯
     *
     * @access public
     */
    function SyL_FilterAuth()
    {
        // ǧڥ֥Ⱥ
        $this->auth =& SyL_Auth::singleton();
    }

    /**
     * ǧȽ or ǧڼ¹
     *
     * @access public
     * @param object ǡ֥
     */
    function preAction(&$data)
    {
        // ǧڥꥢȽ
        if ($this->auth->isAuthArea()) {
            // 󥢥Ƚ
            if ($this->auth->isLoginAction()) {
                // ¹
                $this->login = $this->auth->doLogin();
                if (!$this->login) {
                    // å󥨥顼̤إ쥯
                    SyL_Auth::redirectLoginError();
                }
            } else {
                // ֤Ƚ
                if (!$this->auth->isLogin()) {
                    // ̤ξ
                    // å󥨥顼̤إ쥯
                    SyL_Auth::redirectSessionError();
                }
            }
        }
    }

    /**
     * ϡTOP̤˥쥯
     *
     * @access public
     * @param object ǡ֥
     */
    function postAction(&$data)
    {
        // ǧڥꥢȽ
        if (is_bool($this->login) && $this->login) {
            // TOPإ쥯
            SyL_Auth::redirectTop();
        }
    }
}

?>
